==> haskell-recursion-schemes-5.2.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 recursion-schemes
version:              5.2.1
visibility:           public
id:                   recursion-schemes-5.2.1-oXoN7K5X4U2TFUoCPbEQ9
key:                  recursion-schemes-5.2.1-oXoN7K5X4U2TFUoCPbEQ9
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Oleg Grenrus" <oleg.grenrus@iki.fi>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  3b9dba3878f6d8e39adcbc2701cb811e
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-8.10.2/site-local/recursion-schemes-5.2.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/recursion-schemes-5.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/recursion-schemes-5.2.1
hs-libraries:         HSrecursion-schemes-5.2.1-oXoN7K5X4U2TFUoCPbEQ9
depends:
    base-4.14.1.0 base-orphans-0.8.3-932vJJ8cPb2JsL8TDJOkHX
    comonad-5.0.6-HcNC6nJAeXXEnLLq9LjN4q containers-0.6.2.1
    data-fix-0.3.0-4V5RtI8gbu4VkzZRRg0bG
    free-5.1.4-1CYXBGAiHmDDYns6ayqqpq template-haskell-2.16.0.0
    th-abstraction-0.4.0.0-EowzxylgIS6DLmPFoxbMpZ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recursion-schemes-5.2.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 recursion-schemes
version:              5.2.1
visibility:           public
id:                   recursion-schemes-5.2.1-JE1jZhQN5a09zfehStjUjZ
key:                  recursion-schemes-5.2.1-JE1jZhQN5a09zfehStjUjZ
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Oleg Grenrus" <oleg.grenrus@iki.fi>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  1933d3d82b6978f864f41926b5515d4e
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-8.10.2/site-local/recursion-schemes-5.2.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/recursion-schemes-5.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/recursion-schemes-5.2.1
hs-libraries:         HSrecursion-schemes-5.2.1-JE1jZhQN5a09zfehStjUjZ
depends:
    base-4.14.1.0 base-orphans-0.8.4-B3FkH8D2O6b3tLYPhKsLNi
    comonad-5.0.6-3L9cUHGzM6h6c8YPSqjxek containers-0.6.2.1
    data-fix-0.3.0-8Ml4zcJWScRBPDRBNUmzRw
    free-5.1.5-KZ6DfxnFtNALE5CKC5NErZ template-haskell-2.16.0.0
    th-abstraction-0.4.1.0-A7JgjUrazebFmefKqpqS0Q transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
